
// Self Destructing Message (Written in Arduino 22)
// -------------------------
// Franky Alfaro
// May 27, 2012
// ------------------------------------------------------------------------------
/* This Program Reads a "secret" message stored on an FRAM chip, stores 
   the message into a char array, then displays the message on an
   SSD1306 OLED display. After a set amount of time, the display will read
   "This message will self destruct in 5 seconds" then counts down. When the 
   countdown completes, the display is erased, FRAM memory is erased, and the
   "cache" char array is erased(ALL written over), and the message self destructs.
   To initially load a message/data onto the FRAM, the "Create_Mission_Objective" 
   sketch must first be uploaded to the arduino, then upload this sketch afterwards.
   ---------------------------------------------------------------------------------
*/

/* -------------------------------------------------------------------------------
   RAMTRON FM24C04 Connections to Arduino
   --------------------------------------
   pinout:  Breakout | Arduino
             GND        GND
             VCC        +5V
             SDA        A4
             SCL        A5
   ---------------------------------------------------------------------------------------------
   FM24C04: http://ramtron.com/products/nonvolatile-memory/serial-product.aspx?id=141 (Datasheet)
   ----------------------------------------------------------------------------------------------
*/

/* -------------------------------------------------------------------------------
   SSD1306 OLED Display(from WIDE.HK, Breakout board, USE level shifter)
   -------------------------------------------------------------------------------
   pinout:  SSD1306 | Arduino
              SCLK      D13
              SDIN      D11
              3V3       +3.3V
              RS        D08
              CS        D10
              RES       D07
   ----------------------------------------------------------------------------------
   ADAFRUIT: https://www.adafruit.com/products/326 (product page)
   TUTORIAL: http://ladyada.net/products/oled12864/ (Connecting to an Arduino)
   ----------------------------------------------------------------------------------
*/

/* Special Thanks:
   Adafruit: for SSD1306 library, example code, tutorials, Arduino
   NickGammon: Hardware SPI library modification 
   Professors: General inspiration to work on new projects to get better understanding
               on how circuits work.
*/
   
#include <Wire.h>         
#include <SSD1306.h>
#include <SPI.h>

#define OLED_DC 8
#define OLED_CS 10     
#define OLED_CLK 13    
#define OLED_MOSI 11   
#define OLED_RESET 7   
    
SSD1306 oled(OLED_MOSI, OLED_CLK, OLED_DC, OLED_RESET, OLED_CS);

// Array_size needs to be changed to the size of your char array written to fm24c04
const int array_size = 76;

// data from FRAM is written to "cache" array, then overwritten when self destruct occurs
char cache[array_size];

// address of the FRAM memory, 1010 is 24c04 address, 00 is A2 and A1, and 0 is page address 
int ramtron = B1010000;

//first available address
int first_word = B00000000; 

//button connected to digital pin 6
int button = 6;

boolean message = false;


///// ***END DECLARE*** /////////////////////////////////
////////////////////////////////////////////////////////

void setup()
{
  pinMode(button, INPUT);
  Serial.begin(9600);
  Wire.begin();
  SPI.begin();
  //OLED chargepump
  oled.ssd1306_init(SSD1306_SWITCHCAPVCC); 
}
///// ***END SETUP*** ////////////////////////////////
/////////////////////////////////////////////////////

void loop()
{
  
  if(digitalRead(button) == 0)
  {
  idle_screen();
  }
  else if(digitalRead(button) == 1)
  {
  read_ramtron();
  display_message();
  erase_allTraces();
  }
  delay(10);
}
///// ***END LOOP*** ///////////////////////////////
///////////////////////////////////////////////////

// This function is just a logo that floats across the screen... No hidden messages here...or is there?
void idle_screen() 
{
  
// Dimensions of the "LABZ" image, followed by the hex code that produces the image
#define LABZ_HEIGHT 64 
#define LABZ_WIDTH  128 
 static unsigned char __attribute__ ((progmem)) LABZ[]={
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE8, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE,
0xEE, 0xEE, 0x6E, 0x08, 0x80, 0xE0, 0xEC, 0xEE, 0xEE, 0x0E, 0x0E, 0x0E, 0xCE, 0xEE, 0xEE, 0xEE,
0x6E, 0x00, 0xE0, 0xEC, 0xEC, 0xEE, 0x0E, 0xCE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0x6E, 0x06, 0xE0,
0xEE, 0xEE, 0xEE, 0x0E, 0x00, 0x00, 0xC0, 0xEC, 0xEE, 0xEE, 0x2E, 0x06, 0x00, 0xEC, 0xEE, 0xEE,
0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0x2E, 0x06, 0x00, 0xE0, 0xEE, 0xEE, 0xEE, 0x0E, 0x02,
0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xE0, 0xE0, 0xE8, 0xEC, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE,
0xE0, 0x00, 0x00, 0xE8, 0xEC, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0xEE, 0x2C, 0x00,
0x00, 0x0C, 0x0E, 0x0E, 0x8E, 0xCE, 0xEE, 0xEE, 0xEE, 0x6E, 0x2E, 0x0E, 0x0E, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x18, 0x1F, 0x1F, 0x1F, 0x0F, 0x01, 0x00, 0x00, 0x00, 0x1C, 0x1F, 0x1F,
0x1F, 0x03, 0x00, 0x00, 0x0F, 0x0F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1E, 0x1F, 0x0F, 0x07, 0x03,
0x00, 0x0F, 0x0F, 0x1F, 0x1F, 0x1D, 0x1C, 0x1C, 0x1C, 0x1F, 0x0F, 0x07, 0x03, 0x00, 0x0F, 0x0F,
0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1E, 0x1F, 0x1F, 0x1F, 0x03, 0x00, 0x18, 0x1F, 0x1F, 0x1F, 0x1F,
0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x00, 0x00, 0x18, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1C, 0x1C,
0x1C, 0x1C, 0x1C, 0x1C, 0x1E, 0x1F, 0x1F, 0x07, 0x03, 0x01, 0x00, 0x00, 0x00, 0x0F, 0x1F, 0x1F,
0x1F, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x0F, 0x07, 0x00, 0x18,
0x1C, 0x1E, 0x1E, 0x1F, 0x1F, 0x1F, 0x1D, 0x1C, 0x1C, 0x1C, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00


};

//used for counters
int x;
int y;

oled.clear();

  
  for(int i=0; i<26; i++)
  {
  oled.drawbitmap(0, y,  LABZ, 128, 64, 1);
  oled.display();
  x = x+=2;
  y = y+=1;
  delay(20);
  oled.clear();
  }
  
  for(int i=26; i>0; i--)
  {
    oled.drawbitmap(0, y,  LABZ, 128, 64, 1);
  oled.display();
  x = x+=2;
  y = y-=1;
  delay(30);
  oled.clear();
  }

  
}
///// ***END IDLE_SCREEN*** //////////////////////
/////////////////////////////////////////////////

// Had to add a logo of the "secret agency" , for fun   
void mission_splashscreen() 
{
  
// Dimensions of the "LABZ" image, followed by the hex code that produces the image
#define IMF_HEIGHT 64 
#define IMF_WIDTH  128
 static unsigned char __attribute__ ((progmem)) IMF[]={ 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xFC, 0xFC, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xC0, 0x00, 0x00, 0xF8,
0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0x78, 0x38, 0x38, 0x38, 0x18, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xFC, 0xFC, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x30, 0x70, 0xF0, 0xF0, 0xF0,
0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0xF0, 0xF0, 0xF0,
0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0x70, 0x30, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x3F, 0xFF, 0xFF, 0x00, 0xF0, 0xFF,
0xFF, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0xE0, 0xE0, 0xE0, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x30, 0x70, 0xF0, 0xF0, 0xF0, 0xF0,
0xF0, 0xF0, 0xF0, 0xF0, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0xF0, 0xF0, 0xF0, 0xF0,
0xF0, 0xF0, 0xF0, 0xF0, 0x70, 0x30, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01,
0x03, 0x07, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF,
0x07, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF,
0x07, 0x80, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03,
0x07, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x07,
0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,
0x78, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x03, 0x03, 0x01, 0x01, 0x03, 0x03, 0x07, 0x0F, 0x1F, 0x1F,
0x3F, 0x78, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x1F, 0x1F, 0x1F, 0x1F, 0x00, 0x00, 0x1F, 0x1F, 0x1F, 0x00, 0x01, 0x1F, 0x1F, 0x1F, 0x0F,
0x00, 0x1F, 0x1F, 0x1F, 0x1F, 0x00, 0x1F, 0x1F, 0x1F, 0x1F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x78,
0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x03, 0x03, 0x01, 0x01, 0x03, 0x03, 0x07, 0x0F, 0x1F, 0x1F, 0x3F,
0x78, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};

/* order of command:
   clear display -> write to display -> display what was sent
*/
oled.clear();
oled.drawbitmap(0, 0,  IMF, 128, 64, 1);
oled.display();
delay(3000);

}
///// ***END MISSION_SPLASHSCREEN*** /////////////////////
/////////////////////////////////////////////////////////

// This function read the contents of the FRAM, up to "array_size" address; ignores the rest
void read_ramtron()
{
  /*This small square of code looks like a write function, but it serves the purpose of 
    setting the internal address latch to the desired adress to read. a write function
    is sent to the FM24c04, but before any data is written to the chip, a Wire.endTransmission
    terminates the write. The latch is left at this address, and a read function can follow.
  */
  ///////////////////////////////////////////////////////////////////////////////////////////
  Serial.println("begin Mission briefing:");                                               //                                                                         //
  Wire.beginTransmission(ramtron); // start talking device with address "ramtron" (int)    //
  Wire.send(first_word);                                                                   //
  Wire.endTransmission();                                                                  //
  ///////////////////////////////////////////////////////////////////////////////////////////
  Wire.beginTransmission(ramtron);
  
  //loop to read memory
  
        for(int j=0; j<array_size; j++)
            {
              Wire.requestFrom(ramtron, 1);
              cache[j] = Wire.receive();
              //Uncomment following lines to view message in the Serial Monitor
              Serial.print(cache[j]);
            }
            Serial.println("\nEnd Mission Briefing");
            Serial.println("\n");
           
            
           
  delay(100);
}
///// ***END READ_RAMTRON*** ///////////////////////////
///////////////////////////////////////////////////////



void display_message()
{
  //check if the flag has been tripped
  if(message == false)
  {
    mission_splashscreen();
    //Displays the contents of cache array on the oled display
  oled.clear();
  oled.drawstring(0, 0, cache);
  oled.display();
  delay(7000);
  oled.clear();
  message = true;
  self_destruct();
}
  //if flag is tripped, run this loop
  else if(message == true)
  {
    //if message has already been read, display something else
    oled.clear();
    oled.drawstring(0,0, "Nothing to see here!");
    oled.display();
    delay(3000);
    oled.clear();
  }
}
///// ***END DISPLAY_MESSAGE*** ////////////////////////
///////////////////////////////////////////////////////



// Erases all traces of hiiden message. (display, cache array, FRAM contents);
void erase_allTraces()
{
  int first = 0;
  
  //Erased the oled display
  oled.clear();
  
      for(int i=0; i<array_size; i++)
          {
            //Overwrites cache array
            cache[i] = 'x';
            
          Wire.beginTransmission(ramtron); // start talking to device with address "ramtron" 
          Wire.send(first); 
          
           //Overwrites FRAM memory
          Wire.send('X'); //sends one character at a time
          Wire.endTransmission(); // stop talking to the device
          first = first+1;
          }
      
 delay(1000); // delay one second
}
///// ***END ERASE_ALLTRACES*** ///////////////////////
//////////////////////////////////////////////////////

void self_destruct()
{
  oled.clear();
  oled.drawstring(0, 3, "  This Message Will");
  oled.drawstring(0, 4, "    Self Destruct");
  oled.drawstring(0, 5, "    In 5 Seconds");
  oled.display();
  delay(5000);
  oled.clear();
}
///// ***END SELF_DESTRUCT*** ////////////////////////////////
/////////////////////////////////////////////////////////////
   

